summaryrefslogtreecommitdiffstats
path: root/slv2
diff options
context:
space:
mode:
Diffstat (limited to 'slv2')
-rw-r--r--slv2/Makefile.am2
-rw-r--r--slv2/plugin.h8
-rw-r--r--slv2/pluginlist.h2
-rw-r--r--slv2/slv2.h2
-rw-r--r--slv2/types.h2
-rw-r--r--slv2/world.h (renamed from slv2/model.h)58
6 files changed, 37 insertions, 37 deletions
diff --git a/slv2/Makefile.am b/slv2/Makefile.am
index 2c69aef..e20cde8 100644
--- a/slv2/Makefile.am
+++ b/slv2/Makefile.am
@@ -4,7 +4,7 @@ slv2include_HEADERS = \
lv2.h \
types.h \
slv2.h \
- model.h \
+ world.h \
plugin.h \
port.h \
pluginlist.h \
diff --git a/slv2/plugin.h b/slv2/plugin.h
index 7b8d62b..47cb9ee 100644
--- a/slv2/plugin.h
+++ b/slv2/plugin.h
@@ -31,12 +31,12 @@ extern "C" {
/** \defgroup data Plugin data access
*
- * These functions work exclusively with the plugin's RDF data file.
+ * These functions work exclusively with the plugin's RDF data.
* They do not load or access the plugin dynamic library in any way.
*
- * An SLV2Plugin is a weak reference (ie URIs) to an LV2 plugin in the
- * Model. Most functions which operate on an SLV2Plugin actually query
- * the data in the model.
+ * An SLV2Plugin contains an in-memory cache of the plugin data, loaded
+ * on demand. Duplicating plugins should be avoided when possible for
+ * performance reasons.
*
* @{
*/
diff --git a/slv2/pluginlist.h b/slv2/pluginlist.h
index c0c1b4d..cd1bbf8 100644
--- a/slv2/pluginlist.h
+++ b/slv2/pluginlist.h
@@ -32,7 +32,7 @@ typedef void* SLV2Plugins;
/** \defgroup plugins Plugin lists
*
* These functions work with lists of plugins which come from an
- * SLV2Model. These lists contain only a weak reference to an LV2 plugin
+ * SLV2World. These lists contain only a weak reference to an LV2 plugin
* in the Model.
*
* @{
diff --git a/slv2/slv2.h b/slv2/slv2.h
index 8691e28..431bd17 100644
--- a/slv2/slv2.h
+++ b/slv2/slv2.h
@@ -24,7 +24,7 @@ extern "C" {
#endif
#include <slv2/types.h>
-#include <slv2/model.h>
+#include <slv2/world.h>
#include <slv2/plugin.h>
#include <slv2/port.h>
#include <slv2/pluginlist.h>
diff --git a/slv2/types.h b/slv2/types.h
index da53069..f0f9b7f 100644
--- a/slv2/types.h
+++ b/slv2/types.h
@@ -47,7 +47,7 @@ typedef struct _Port* SLV2Port;
typedef struct _Plugin* SLV2Plugin;
-typedef struct _Model* SLV2Model;
+typedef struct _World* SLV2World;
#ifdef __cplusplus
}
diff --git a/slv2/model.h b/slv2/world.h
index 4db1b2f..4f5b252 100644
--- a/slv2/model.h
+++ b/slv2/world.h
@@ -16,8 +16,8 @@
* 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
*/
-#ifndef __SLV2_MODEL_H__
-#define __SLV2_MODEL_H__
+#ifndef __SLV2_WORLD_H__
+#define __SLV2_WORLD_H__
#include <slv2/pluginlist.h>
@@ -26,15 +26,15 @@ extern "C" {
#endif
-/** \defgroup model Data model loading
+/** \defgroup world Library context, data loading, etc.
*
* These functions deal with the data model which other SLV2 methods
- * operate with. The data model is LV2 data loaded from bundles, from
- * which you can query plugins, etc.
+ * operate with. The world contains an in-memory cache of all bundles
+ * manifest.ttl files, from which you can quickly query plugins, etc.
*
* Normal hosts which just want to easily load plugins by URI are strongly
* recommended to simply find all installed data in the recommended way with
* \ref slv2_model_load_all rather than find and load bundles manually.
*
* Functions are provided for hosts that wish to access bundles explicitly and
* individually for some reason, this is intended for hosts which are tied to
@@ -44,20 +44,20 @@ extern "C" {
*/
-/** Create a new, empty model.
+/** Initialize a new, empty world.
*/
-SLV2Model
-slv2_model_new();
+SLV2World
+slv2_world_new();
-/** Destroy a model.
+/** Destroy the world, mwahaha.
*
* NB: Destroying a model will leave dangling references in any plugin lists,
* plugins, etc. Do not destroy a model until you are finished with all
* objects that came from it.
*/
void
-slv2_model_free(SLV2Model model);
+slv2_world_free(SLV2World world);
/** Load all installed LV2 bundles on the system
@@ -72,7 +72,7 @@ slv2_model_free(SLV2Model model);
* without a special reason to do so - use this one.
*/
void
-slv2_model_load_all(SLV2Model model);
+slv2_world_load_all(SLV2World world);
/** Load all bundles found in \a search_path.
@@ -81,15 +81,15 @@ slv2_model_load_all(SLV2Model model);
* should contain LV2 bundle directories (ie the search path is a list of
* parent directories of bundles, not a list of bundle directories).
*
* If \a search_path is NULL, \a model will be unmodified.
* Use of this function is \b not recommended. Use \ref slv2_model_load_all.
*/
void
-slv2_model_load_path(SLV2Model model,
+slv2_world_load_path(SLV2World world,
const char* search_path);
/** Load a specific bundle into \a model.
*
* \arg bundle_base_uri is a fully qualified URI to the bundle directory,
* with the trailing slash, eg. file:///usr/lib/lv2/someBundle/
@@ -103,37 +103,37 @@ slv2_model_load_path(SLV2Model model,
* the same package).
*/
void
-slv2_model_load_bundle(SLV2Model model,
+slv2_world_load_bundle(SLV2World world,
const char* bundle_base_uri);
/** Add all plugins present in \a model to \a list.
*
* Returned plugins contain a reference to this model, model must not be
* destroyed until plugins are finished with.
*/
SLV2Plugins
-slv2_model_get_all_plugins(SLV2Model model);
+slv2_world_get_all_plugins(SLV2World world);
/** Get plugins filtered by a user-defined filter function.
*
* All plugins in \a model that return true when passed to \a include
* (a pointer to a function that takes an SLV2Plugin and returns a bool)
* will be added to \a list.
*
* Returned plugins contain a reference to this model, model must not be
* destroyed until plugins are finished with.
*/
SLV2Plugins
-slv2_model_get_plugins_by_filter(SLV2Model model,
+slv2_world_get_plugins_by_filter(SLV2World world,
bool (*include)(SLV2Plugin));
#if 0
/** Get plugins filtered by a user-defined SPARQL query.
*
* This is much faster than using slv2_model_get_plugins_by_filter with a
* filter function which calls the various slv2_plugin_* functions.
*
* \param query A valid SPARQL query which SELECTs a single variable, which
@@ -148,11 +148,11 @@ SELECT DISTINCT ?plugin WHERE {
}
\endverbatim </tt>
*
* Returned plugins contain a reference to this model, model must not be
* destroyed until plugins are finished with.
*/
SLV2Plugins
-slv2_model_get_plugins_by_query(SLV2Model model,
+slv2_world_get_plugins_by_query(SLV2World world,
const char* query);
#endif
@@ -162,5 +162,5 @@ slv2_model_get_plugins_by_query(SLV2Model model,
}
#endif
-#endif /* __SLV2_MODEL_H__ */
+#endif /* __SLV2_WORLD_H__ */
@@ -26,15 +26,15 @@ extern "C" {
* Normal hosts which just want to easily load plugins by URI are strongly
* recommended to simply find all installed data in the recommended way with
- * \ref slv2_model_load_all rather than find and load bundles manually.
+ * \ref slv2_world_load_all rather than find and load bundles manually.
*
* Functions are provided for hosts that wish to access bundles explicitly and
@@ -44,20 +44,20 @@ extern "C" {
*
- * NB: Destroying a model will leave dangling references in any plugin lists,
- * plugins, etc. Do not destroy a model until you are finished with all
+ * NB: Destroying the world will leave dangling references in any plugin lists,
+ * plugins, etc. Do not destroy the world until you are finished with all
* objects that came from it.
*/
@@ -81,15 +81,15 @@ slv2_model_load_all(SLV2Model model);
* parent directories of bundles, not a list of bundle directories).
*
- * If \a search_path is NULL, \a model will be unmodified.
- * Use of this function is \b not recommended. Use \ref slv2_model_load_all.
+ * If \a search_path is NULL, \a world will be unmodified.
+ * Use of this function is \b not recommended. Use \ref slv2_world_load_all.
*/
void
@@ -81,15 +81,15 @@ slv2_model_load_all(SLV2Model model);
const char* search_path);
-/** Load a specific bundle into \a model.
+/** Load a specific bundle into \a world.
*
* \arg bundle_base_uri is a fully qualified URI to the bundle directory,
@@ -103,37 +103,37 @@ slv2_model_load_path(SLV2Model model,
const char* bundle_base_uri);
-/** Add all plugins present in \a model to \a list.
+/** Add all plugins present in \a world to \a list.
*
@@ -103,37 +103,37 @@ slv2_model_load_path(SLV2Model model,
*
- * Returned plugins contain a reference to this model, model must not be
+ * Returned plugins contain a reference to this world, world must not be
* destroyed until plugins are finished with.
*/
@@ -103,37 +103,37 @@ slv2_model_load_path(SLV2Model model,
/** Get plugins filtered by a user-defined filter function.
*
- * All plugins in \a model that return true when passed to \a include
+ * All plugins in \a world that return true when passed to \a include
* (a pointer to a function that takes an SLV2Plugin and returns a bool)
* will be added to \a list.
@@ -103,37 +103,37 @@ slv2_model_load_path(SLV2Model model,
* will be added to \a list.
*
- * Returned plugins contain a reference to this model, model must not be
+ * Returned plugins contain a reference to this world, world must not be
* destroyed until plugins are finished with.
*/
@@ -103,37 +103,37 @@ slv2_model_load_path(SLV2Model model,
/** Get plugins filtered by a user-defined SPARQL query.
*
- * This is much faster than using slv2_model_get_plugins_by_filter with a
+ * This is much faster than using slv2_world_get_plugins_by_filter with a
* filter function which calls the various slv2_plugin_* functions.
*
@@ -148,11 +148,11 @@ SELECT DISTINCT ?plugin WHERE {
\endverbatim </tt>
*
- * Returned plugins contain a reference to this model, model must not be
+ * Returned plugins contain a reference to this world, world must not be
* destroyed until plugins are finished with.
*/